@@ -74,7 +74,7 @@ function createPrivateKey (keyBitsize, options, callback) {
 
   params.push(keyBitsize)
 
-  openssl.exec(params, 'RSA PRIVATE KEY', function (sslErr, key) {
+  openssl.exec(params, 'PRIVATE KEY', function (sslErr, key) {
     function done (err) {
       if (err) {
         return callback(err)
